Learn R Programming

africamonitor (version 0.2.4)

.AMID: Global Identifier Macros

Description

The macro .AMID contains the string c("ISO3", "Series") denoting the names of ID variables that identify the cross-sectional dimension in the database.

The macro .AMT contains the string c("Date", "Year", "Quarter", "FY", "QFY", "Month", "Day") denoting temporal identifiers generated by am_expand_date. The "Date" variable is sufficient to uniquely identify a point in time in the database.

Each value in the database is uniquely identified by ISO3, Series and Date.

Usage

.AMID
.AMT

Arguments

See Also

africamonitor

Examples

Run this code
.AMID
.AMT


Run the code above in your browser using DataLab