am_pivot_wider: Reshape Long API Data to Column-Based Format
Description
This function automatically reshapes long (stacked) raw data from the API (am_data(..., wide = FALSE)) to a wide format where each variable has its own column.
It can also be used as a general purpose reshaping command - with an additional capability to handle variable labels.
# \donttest{# Return all indicators for Kenya and Nigeria from the year 2000 onwardsam_pivot_wider(am_data(c("KEN", "NGA"), from = 2000, wide = FALSE))
# }