A data.table with information about the available series in the database.
Arguments
dsid
character. (Optional) id's of datasources matching the 'DSID' column of the data sources table (retrieved using am_sources()) for which series information is to be returned.
source.info
logical. TRUE returns additional information from the data sources table (the source, the frequency of the data and when it was last updated).
ordered
logical. TRUE returns the series in a fixed order, while FALSE returns the result in a random order, to the benefit of faster query execution.
return.query
logical. TRUE will not query the database but instead return the constructed SQL query as a character string (for debugging purposes).
Details
The series table gives information about all of the time series in the database. Each series is given a unique code, and
has a label describing the series. Further information recorded are the minimum and maximum time coverage, and (optionally) a separate series source and url.
The default source.info = TRUE adds the source, the frequency of the data (homogeneous within source), and the date when the source was last updated.
# \donttest{# By default returns all series with additional informationam_series()
# Raw series tableam_series(source.info = FALSE)
# Only series in the WEOam_series("IMF_WEO")
# }